@@ -2,7 +2,7 @@
 
 from .artifact_source import artifact_sources
 
-from .board import create_board, boards, get_board
+from .board import create_board, boards, get_board, results
 
 
 import jiggy.jiggyboard.jb_wandb as wandb
